@@ -81,6 +81,15 @@ class ContainerTechnology:
         """
         pass
 
+    def module_dir(self, name):
+        """
+        Get the module directory the container references
+        """
+        # If the user provided a tag, tags are converted to folders
+        if ":" in name:
+            name = name.replace(":", os.sep)
+        return os.path.join(self.settings.module_base, name)
+
     def container_dir(self, name):
         """
         Use a custom container directory, otherwise default to module dir.
@@ -93,6 +102,15 @@ class ContainerTechnology:
             return os.path.join(self.settings.module_base, name)
         return os.path.join(self.settings.container_base, name)
 
+    def clean_labels(self, labels):
+        """
+        Clean labels, meaning removing newlines and replacing with label separator
+        """
+        updated_labels = {}
+        for key, value in labels.items():
+            updated_labels[key] = value.replace("\n", self.settings.label_separator)
+        return updated_labels
+
     def guess_tag(self, module_name, allow_fail=False):
         """
         If a user asks for a name without a tag, try to figure it out.
@@ -125,8 +143,8 @@ class ContainerTechnology:
         """
         module_name = self.guess_tag(module_name)
 
-        # This can be the module or container directory
-        container_dir = self.container_dir(module_name)
+        # The environment file is stored in the module directory
+        container_dir = self.module_dir(module_name)
 
         # Does the user want to see a module file?
         result = os.path.join(container_dir, self.settings.environment_file)
